@@ -7,7 +7,7 @@ use MooX::Types::MooseLike::Base qw(:all);
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 use Carp;
 
 #######
@@ -65,7 +65,7 @@ has 'experimental' => (
 has 'format' => (
 	is  => 'ro',
 	isa => sub {
-		my $format = { dsl => 1, mi => 1, build => 1, dzil => 1, dist => 1, cfile => 1, };
+		my $format = { dsl => 1, mi => 1, build => 1, dzil => 1, dist => 1, cpanfile => 1, };
 		croak 'not a supported output format' unless defined $format->{ $_[0] };
 		return;
 	},
@@ -225,7 +225,7 @@ App::Midgen::Roles - Package Options and Attributes used by L<App::Midgen>
 
 =head1 VERSION
 
-This document describes App::Midgen::Roles version: 0.20
+This document describes App::Midgen::Roles version: 0.21
 
 =head1 METHODS
 
